<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_AT">
<context>
    <name>GuidelineEditDialog</name>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="14"/>
        <source>Edit guideline...</source>
        <translation>Hilfslinie bearbeiten...</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="22"/>
        <source>Page:</source>
        <translation>Seite:</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="36"/>
        <source>Position:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="59"/>
        <source>cm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="64"/>
        <source>in</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="69"/>
        <source>bp</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PaperSize</name>
    <message>
        <location filename="../src/PaperSizes.cpp" line="24"/>
        <source>Beamer 16:10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="25"/>
        <source>Beamer 16:9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="26"/>
        <source>Beamer 14:9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="27"/>
        <source>Beamer 1.41:1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="28"/>
        <source>Beamer 5:4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="29"/>
        <source>Beamer 4:3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="30"/>
        <source>Beamer 3:2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="33"/>
        <source>Screen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="36"/>
        <source>DIN 4A0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="37"/>
        <source>DIN 2A0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="38"/>
        <source>DIN A0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="39"/>
        <source>DIN A1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="40"/>
        <source>DIN A2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="41"/>
        <source>DIN A3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="42"/>
        <source>DIN A4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="43"/>
        <source>DIN A5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="44"/>
        <source>DIN A6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="45"/>
        <source>DIN A7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="46"/>
        <source>DIN A8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="47"/>
        <source>DIN A9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="48"/>
        <source>DIN A10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="49"/>
        <source>DIN B0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="50"/>
        <source>DIN B1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="51"/>
        <source>DIN B2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="52"/>
        <source>DIN B3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="53"/>
        <source>DIN B4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="54"/>
        <source>DIN B5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="55"/>
        <source>DIN B6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="56"/>
        <source>DIN B7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="57"/>
        <source>DIN B8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="58"/>
        <source>DIN B9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="59"/>
        <source>DIN B10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="60"/>
        <source>DIN C0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="61"/>
        <source>DIN C1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="62"/>
        <source>DIN C2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="63"/>
        <source>DIN C3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="64"/>
        <source>DIN C4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="65"/>
        <source>DIN C5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="66"/>
        <source>DIN C6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="67"/>
        <source>DIN C7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="68"/>
        <source>DIN C8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="69"/>
        <source>DIN C9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="70"/>
        <source>DIN C10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="71"/>
        <source>DIN DL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="72"/>
        <source>DIN DLE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="73"/>
        <source>DIN C6/C5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="74"/>
        <source>DIN RA0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="75"/>
        <source>DIN RA1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="76"/>
        <source>DIN RA2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="77"/>
        <source>DIN RA3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="78"/>
        <source>DIN RA4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="79"/>
        <source>DIN SRA0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="80"/>
        <source>DIN SRA1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="81"/>
        <source>DIN SRA2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="82"/>
        <source>DIN SRA3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="83"/>
        <source>DIN SRA4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="84"/>
        <source>SIS D0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="85"/>
        <source>SIS D1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="86"/>
        <source>SIS D2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="87"/>
        <source>SIS D3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="88"/>
        <source>SIS D4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="89"/>
        <source>SIS D5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="90"/>
        <source>SIS D6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="91"/>
        <source>SIS D7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="92"/>
        <source>SIS D8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="93"/>
        <source>SIS D9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="94"/>
        <source>SIS E0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="95"/>
        <source>SIS E1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="96"/>
        <source>SIS E2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="97"/>
        <source>SIS E3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="98"/>
        <source>SIS E4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="99"/>
        <source>SIS E5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="100"/>
        <source>SIS E6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="101"/>
        <source>SIS E7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="102"/>
        <source>SIS E8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="103"/>
        <source>SIS E9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="104"/>
        <source>SIS F0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="105"/>
        <source>SIS F1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="106"/>
        <source>SIS F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="107"/>
        <source>SIS F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="108"/>
        <source>SIS F4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="109"/>
        <source>SIS F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="110"/>
        <source>SIS F6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="111"/>
        <source>SIS F7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="112"/>
        <source>SIS F8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="113"/>
        <source>SIS F9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="114"/>
        <source>SIS G0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="115"/>
        <source>SIS G1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="116"/>
        <source>SIS G2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="117"/>
        <source>SIS G3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="118"/>
        <source>SIS G4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="119"/>
        <source>SIS G5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="120"/>
        <source>SIS G6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="121"/>
        <source>SIS G7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="122"/>
        <source>SIS G8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="123"/>
        <source>SIS G9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="124"/>
        <source>JIS B0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="125"/>
        <source>JIS B1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="126"/>
        <source>JIS B2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="127"/>
        <source>JIS B3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="128"/>
        <source>JIS B4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="129"/>
        <source>JIS B5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="130"/>
        <source>JIS B6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="131"/>
        <source>JIS B7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="132"/>
        <source>JIS B8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="133"/>
        <source>JIS B9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="134"/>
        <source>JIS B10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="135"/>
        <source>JIS B11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="136"/>
        <source>JIS B12</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="137"/>
        <source>JIS Shiroku ban 4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="138"/>
        <source>JIS Shiroku ban 5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="139"/>
        <source>JIS Shiroku ban 6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="140"/>
        <source>JIS Kiku 4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="141"/>
        <source>JIS Kiku 5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="142"/>
        <source>SAC D0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="143"/>
        <source>SAC D1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="144"/>
        <source>SAC D2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="145"/>
        <source>SAC D3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="146"/>
        <source>SAC D4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="147"/>
        <source>SAC D5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="148"/>
        <source>SAC D6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="150"/>
        <source>Letter (ANSI A)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="151"/>
        <source>Legal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="152"/>
        <source>Tabloid (ANSI B)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="153"/>
        <source>Ledger</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="154"/>
        <source>Junior Legal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="155"/>
        <source>Half Letter</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="156"/>
        <source>Government Letter</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="157"/>
        <source>Government Legal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="158"/>
        <source>ANSI C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="159"/>
        <source>ANSI D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="160"/>
        <source>ANSI E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="161"/>
        <source>Arch A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="162"/>
        <source>Arch B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="163"/>
        <source>Arch C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="164"/>
        <source>Arch D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="165"/>
        <source>Arch E1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="166"/>
        <source>Arch E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="167"/>
        <source>Arch E2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="168"/>
        <source>Arch E3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="201"/>
        <source>mm</source>
        <extracomment>Length unit: millimeters</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="207"/>
        <source>in</source>
        <extracomment>Length unit: inches</extracomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtPDF</name>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="34"/>
        <source>[language name]</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="35"/>
        <source>[translator&apos;s name/email]</source>
        <translation>&lt;a href=&quot;mailto:st.loeffler@gmail.com&quot;&gt;Stefan Löffler&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentScene</name>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="243"/>
        <source>Unlock PDF</source>
        <translation>PDF entsperren</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="243"/>
        <source>Please enter the password to unlock the PDF</source>
        <translation>Bitte geben Sie das Passwort ein, um das PDF zu entsperren</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="259"/>
        <source>Incorrect password</source>
        <translation>Falsches Passwort</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="259"/>
        <source>The password you entered was incorrect.</source>
        <translation>Das Passwort, das Sie eingegeben haben, war falsch.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="265"/>
        <source>This document is locked. You need a password to open it.</source>
        <translation>Dieses Dokument ist gesperrt. Sie benötigen ein Passwort, um es zu öffnen.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="266"/>
        <source>Unlock</source>
        <translation>Entsperren</translation>
    </message>
    <message>
        <location filename="../src/PDFBackend.cpp" line="321"/>
        <source>rendering page</source>
        <translation>Seite wird gerendert</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentView</name>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2264"/>
        <source>Goto page %1</source>
        <translation>Gehe zu Seite %1</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2276"/>
        <source>Execute `%1`</source>
        <translation>Führe `%1` aus</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2541"/>
        <source>Layers</source>
        <translation>Ebenen</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="48"/>
        <location filename="../src/InfoWidgets.cpp" line="65"/>
        <source>Table of Contents</source>
        <translation>Inhaltsverzeichnis</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="157"/>
        <location filename="../src/InfoWidgets.cpp" line="364"/>
        <source>Meta Data</source>
        <translation>Metadaten</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="366"/>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="367"/>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="368"/>
        <source>Author:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="369"/>
        <source>Subject:</source>
        <translation>Betreff:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="370"/>
        <source>Keywords:</source>
        <translation>Schlüsselwörter:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="213"/>
        <location filename="../src/InfoWidgets.cpp" line="374"/>
        <source>Processing</source>
        <translation>Verarbeitung</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="375"/>
        <source>Creator:</source>
        <translation>Verfasser:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="376"/>
        <source>Producer:</source>
        <translation>Hersteller:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="377"/>
        <source>Creation date:</source>
        <translation>Erstellt:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="378"/>
        <source>Modification date:</source>
        <translation>Bearbeitet:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="379"/>
        <source>Trapped:</source>
        <translation>Trapping:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="245"/>
        <location filename="../src/InfoWidgets.cpp" line="381"/>
        <source>Other</source>
        <translation>Sonstiges</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="308"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="311"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="314"/>
        <location filename="../src/InfoWidgets.cpp" line="351"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="390"/>
        <location filename="../src/InfoWidgets.cpp" line="484"/>
        <source>Fonts</source>
        <translation>Schriften</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="485"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="485"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="485"/>
        <source>Subset</source>
        <translation>teilweise</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="485"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="440"/>
        <source>Type 0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="270"/>
        <source>B</source>
        <extracomment>File size: bytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="272"/>
        <source>kB</source>
        <extracomment>File size: kilobytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="274"/>
        <source>MB</source>
        <extracomment>File size: megabytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="276"/>
        <source>GB</source>
        <extracomment>File size: gigabytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="278"/>
        <source>TB</source>
        <extracomment>File size: terabytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="371"/>
        <source>Page size:</source>
        <translation>Seitengröße:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="372"/>
        <source>File size:</source>
        <translation>Dateigröße:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="443"/>
        <source>Type 1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="446"/>
        <source>Type 1 (multiple master)</source>
        <translation>Type 1 (mehrere Master)</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="449"/>
        <source>Type 3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="452"/>
        <source>TrueType</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="455"/>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="455"/>
        <source>no</source>
        <translation>nein</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="458"/>
        <source>[embedded]</source>
        <translation>[eingebettet]</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="461"/>
        <source>[builtin]</source>
        <translation>[intern]</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="493"/>
        <location filename="../src/InfoWidgets.cpp" line="588"/>
        <source>Permissions</source>
        <translation>Berechtigungen</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="590"/>
        <source>Printing:</source>
        <translation>Drucken:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="591"/>
        <source>Modifications:</source>
        <translation>Verändern:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="592"/>
        <source>Extraction:</source>
        <translation>Extrahieren:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="593"/>
        <source>Annotation:</source>
        <translation>Anmerkungen:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="594"/>
        <source>Filling forms:</source>
        <translation>Formulare:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="542"/>
        <location filename="../src/InfoWidgets.cpp" line="551"/>
        <location filename="../src/InfoWidgets.cpp" line="560"/>
        <location filename="../src/InfoWidgets.cpp" line="567"/>
        <location filename="../src/InfoWidgets.cpp" line="572"/>
        <source>Allowed</source>
        <translation>Erlaubt</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="544"/>
        <source>Low resolution only</source>
        <translation>Nur mit niedriger Auflösung</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="547"/>
        <location filename="../src/InfoWidgets.cpp" line="557"/>
        <location filename="../src/InfoWidgets.cpp" line="564"/>
        <location filename="../src/InfoWidgets.cpp" line="569"/>
        <location filename="../src/InfoWidgets.cpp" line="574"/>
        <location filename="../src/InfoWidgets.cpp" line="579"/>
        <location filename="../src/InfoWidgets.cpp" line="580"/>
        <location filename="../src/InfoWidgets.cpp" line="581"/>
        <location filename="../src/InfoWidgets.cpp" line="582"/>
        <location filename="../src/InfoWidgets.cpp" line="583"/>
        <source>Denied</source>
        <translation>Nicht erlaubt</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="553"/>
        <source>Assembling only</source>
        <translation>Nur Zusammenfügen</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="554"/>
        <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
        <translation>Seiten einfügen, löschen, rotieren; Lesezeichen und Vorschaubilder erstellen</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="562"/>
        <source>Accessibility support only</source>
        <translation>Nur Barrierefreiheit</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="602"/>
        <location filename="../src/InfoWidgets.cpp" line="694"/>
        <source>Annotations</source>
        <translation>Anmerkungen</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="695"/>
        <source>Page</source>
        <translation>Seite</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="695"/>
        <source>Subject</source>
        <translation>Betreff</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="695"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="695"/>
        <source>Contents</source>
        <translation>Inhalt</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentTools.cpp" line="978"/>
        <source>Insufficient permission</source>
        <translation>Unzureichende Berechtigung</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentTools.cpp" line="978"/>
        <source>Text extraction is not allowed for this document.</source>
        <translation>Das Kopieren von Text aus diesem Dokument ist nicht erlaubt.</translation>
    </message>
</context>
</TS>
